@@ -33,5 +33,4 @@ def find_bytes_ida(expression, segments=None):
 
 
 def run(segments, args, addresses, interpreter=None, **kwargs):
-    results = find_bytes_ida(args.expression)
-    return addresses + results
+    return addresses + list(find_bytes_ida(args.expression))
