@@ -1,14 +1,14 @@
 from argparse import RawTextHelpFormatter
 from fa import utils
 
-DESCRIPTION = '''intersect two or more checkpoints
+DESCRIPTION = '''intersect two or more variables
 
 EXAMPLE:
     results = [0, 4, 8]
-    checkpoint a
+    store a
     ...
     results = [0, 12, 20]
-    checkpoint b
+    store b
 
     -> intersect a b
     results = [0]
@@ -19,15 +19,15 @@ def get_parser():
     p = utils.ArgumentParserNoExit('intersect',
                                    description=DESCRIPTION,
                                    formatter_class=RawTextHelpFormatter)
-    p.add_argument('checkpoints', nargs='+', help='checkpoint names')
+    p.add_argument('variables', nargs='+', help='variable names')
     return p
 
 
 def run(segments, args, addresses, interpreter=None, **kwargs):
-    first_checkpoint = args.checkpoints[0]
-    results = set(interpreter.checkpoints[first_checkpoint])
+    first_var = args.variables[0]
+    results = set(interpreter.get_variable(first_var))
 
-    for c in args.checkpoints[1:]:
-        results.intersection_update(interpreter.checkpoints[c])
+    for c in args.variables[1:]:
+        results.intersection_update(interpreter.get_variable(c))
 
     return list(results)
