@@ -19,8 +19,6 @@ def get_parser():
     p = utils.ArgumentParserNoExit('verify-bytes',
                                    description=DESCRIPTION,
                                    formatter_class=RawTextHelpFormatter)
-    p.add_argument('--until', type=int,
-                   help='keep advancing by a given size until a match')
     p.add_argument('hex_str')
     return p
 
@@ -34,13 +32,6 @@ def verify_bytes(addresses, hex_str, segments=None, until=None):
     if len(results) > 0:
         return results
 
-    if until:
-        step = until
-        while len(results) == 0:
-            addresses = [ea + step for ea in addresses]
-            results = [ea for ea in addresses
-                       if utils.read_memory(segments, ea, len(magic)) == magic]
-
     return results
 
 
